# Lethai Library
The library, named "lethai", provides a standard library to interact with the services provided by Lethical.ai.


## Getting Started

### Generate API Key
Steps to follow

  - Create an account on Lethical.ai
  - Click on API Keys on the side panel
  - Click "add key" button
    - Provide tags to the key if needed (They will help you identify and filter the keys for your reference)
    - Choose the access level for the key
    - Click on generate
  - A key will be displayed on the screen please copy it and store it safely for future usage.

*NOTE: The key will only be shown once. This is for security purposes*

### Installation
> pip3 install lethai

### Usage
The various features provided by our library include the following:

- Discrimination detection
  -[NLG models](./docs/discrimination.md)
